
dialogId("odp-v-kachna", "font_big", "Doesn’t this duck look suspicious to you?")
dialogStr("Nezdá se ti, že se ta kachna tváří podezřele?")


dialogId("odp-m-zda0", "font_small", "I think it looks dumb.")
dialogStr("Zdá se mi, že se tváří pitomě.")


dialogId("odp-m-zda1", "font_small", "I think it looks inflatable.")
dialogStr("Zdá se mi, že je nafukovací.")


dialogId("odp-v-snehulak", "font_big", "Can you see that snowman?")
dialogStr("Vidíš toho sněhuláka?")


dialogId("odp-m-blaznis", "font_small", "What do you mean? Snowmen belong to the Mess Hall.")
dialogStr("Blázníš? Sněhuláci přeci patří do jídelny.")


dialogId("odp-m-kohout", "font_small", "Try to open that tap!")
dialogStr("Zkus otevřít ten kohoutek!")


dialogId("odp-v-vtip", "font_big", "Now, this was a joke. Heh, heh.")
dialogStr("To byl zase vtip. Heh, heh.")


dialogId("odp-m-predmet", "font_small", "And there isn't even a funny animated object here.")
dialogStr("A není tu žádný veselý animovaný předmět.")


dialogId("odp-v-pozadi", "font_big", "But a beautifully wavy background.")
dialogStr("Zato se tu krásně vlní pozadí.")


dialogId("odp-v-pohni", "font_big", "Move on, so that we can get going.")
dialogStr("Tak sebou pohni, ať se dostaneme dál.")


dialogId("odp-v-coja", "font_big", "And what about me?")
dialogStr("A co já?")


dialogId("odp-v-nestacim", "font_big", "Am I not enough for you now, or what?")
dialogStr("Já už ti nestačím, nebo co?")

